import logging
import sys

LOG_FORMATTER = logging.Formatter(
    fmt='%(asctime)s %(name)s:%(module)s:%(funcName)s:%(lineno)d %(message)s', datefmt='%Y%m%d%H%M%S'
)


class MaxLevelFilter(logging.Filter):
    '''Filters (lets through) all messages with level < LEVEL'''

    def __init__(self, level):
        self.level = level

    def filter(self, record):
        return (
            record.levelno < self.level
        )  # "<" instead of "<=": since logger.setLevel is inclusive, this should be exclusive


def _stream_handler(logstream, loglevel, logname, logfilters=None) -> logging.Handler:
    handler = logging.StreamHandler(logstream)
    handler.setLevel(loglevel)
    handler.set_name(logname)  # type:ignore
    for logfilter in logfilters or []:
        handler.addFilter(logfilter)
    return handler


def get_logger(app_name: str, verbose: bool, quiet: bool, with_file: str = None):
    """
    Sets format to '%(asctime)s %(name)s:%(module)s:%(funcName)s:%(lineno)d %(message)s'  and datefmt to '%Y%m%d%H%M%S',
      either on stdout and stderr or (if set) in the logfile
    Logging format
      %(name)s            Name of the logger (logging channel)
      %(module)s          Module (name portion of filename)
      %(lineno)d          Source line number where the logging call was issued
                          (if available)
      %(funcName)s        Function name
      %(asctime)s         Textual time when the LogRecord was created
      %(process)d         Process ID (if available)
      %(message)s         The result of record.getMessage(), computed just as
                          the record is emitted
    """
    log = logging.getLogger(app_name)
    stderr_handler = _stream_handler(logstream=sys.stderr, loglevel=logging.DEBUG, logname='stderr')
    log.addHandler(stderr_handler)
    stdout_handler = _stream_handler(
        logstream=sys.stdout, loglevel=logging.INFO, logname='stdout', logfilters=[MaxLevelFilter(logging.INFO)]
    )
    log.addHandler(stdout_handler)
    if verbose:
        loglevel = logging.DEBUG
    elif quiet:
        loglevel = logging.ERROR
    else:
        loglevel = logging.INFO
    if with_file:
        logfile = logging.FileHandler(with_file)
        logfile.setLevel(logging.DEBUG)
        logfile.set_name('logfile')  # type:ignore
        log.addHandler(logfile)
        logfile.setFormatter(LOG_FORMATTER)
        log.setLevel(logging.DEBUG)
        stderr_handler.setLevel(loglevel)
    else:
        stdout_handler.setFormatter(LOG_FORMATTER)
        stderr_handler.setFormatter(LOG_FORMATTER)
        log.setLevel(loglevel)
    return log



import curses
import subprocess
import tempfile

import attr

from .comic_screen import ComicScreen


@attr.s
class ComicScreenChafa(ComicScreen):
    output_format: str = attr.ib(default='sixels')

    def __attrs_post_init__(self):
        self._curr_image = None
        self.stdscr = None

    def show(self, image, image_index: int):
        title = f'{image_index + 1}/{self.images_count} - {self.file_name}'
        screen_size = self.stdscr.getmaxyx()
        with tempfile.NamedTemporaryFile(suffix='.png') as image_file:
            image.save(image_file.name)
            self._log.debug(f'Saved {image_file.name}')
            self._log.info(title)
            subprocess.run(
                ['chafa', '-f', self.output_format, '--size', f'{screen_size[1]}x{screen_size[0] - 2}', image_file.name]
            )

    def main_loop_base(self, mgr):
        mgr.show()
        looping = True
        while looping:
            key_event = input()
            if key_event == 'q':
                looping = False
            elif key_event in ('n', 'd', ''):
                mgr.next()
            elif key_event in ('p', 'a'):
                mgr.prev()
            else:
                self._log.info(key_event)

    def main_loop(self, mgr):
        try:
            curses.wrapper(self._manage_keys, mgr)
        except Exception as e:
            self._log.debug(f'Unable to use curses: {e}')
            self.main_loop_base(mgr)

    def _manage_keys(self, stdscr, mgr):
        self.stdscr = stdscr
        curses.curs_set(0)
        looping = True
        # make sure the first image is shown
        curses.ungetch(curses.KEY_RESIZE)
        while looping:
            key_event = stdscr.getkey()
            if key_event in ('q',):
                looping = False
            elif key_event in ('n', 'd', 'KEY_RIGHT'):
                mgr.next()
            elif key_event in ('p', 'a', 'KEY_LEFT'):
                mgr.prev()
            elif key_event == 'KEY_RESIZE':
                self._log.debug('WINDOWSIZECHANGED')
                mgr.show(image_changed=False)
            else:
                self._log.info(key_event)



from unittest import mock
import pytest

from oilele.oilala import main


@pytest.fixture
def mock_pil_image(monkeypatch):
    mock_obj = mock.MagicMock(name='PIL.Image')
    monkeypatch.setattr('oilele.oilala.Image', mock_obj)
    yield mock_obj
    print(f'{mock_obj} calls: {mock_obj.mock_calls}')


@pytest.fixture
def mock_pdf2image(monkeypatch):
    mock_obj = mock.MagicMock(name='pdf2image')
    monkeypatch.setattr('oilele.oilala.pdf2image', mock_obj)
    yield mock_obj
    print(f'{mock_obj} calls: {mock_obj.mock_calls}')


@pytest.fixture
def mock_pygame(monkeypatch):
    mock_obj = mock.MagicMock(name='pygame')
    mock_obj.display.set_mode.return_value.get_size.return_value = (100, 150)
    mock_events = (
        mock.Mock(name='event1'),
        mock.Mock(name='event2'),
        mock.Mock(name='event3', type=mock_obj.QUIT),
    )
    mock_obj.event.get.return_value = mock_events
    mock_obj.vernum.major = 2
    monkeypatch.setattr('oilele.screen.comic_screen_pygame.pygame', mock_obj)
    yield mock_obj, mock_events
    print(f'{mock_obj} calls: {mock_obj.mock_calls}')
    for mock_event in mock_events:
        print(f'{mock_event} calls: {mock_event.mock_calls}')


@pytest.fixture
def mock_subprocess(monkeypatch):
    mock_obj = mock.MagicMock(name='subprocess')
    monkeypatch.setattr('oilele.screen.comic_screen_chafa.subprocess', mock_obj)
    yield mock_obj
    print(f'{mock_obj} calls: {mock_obj.mock_calls}')


@pytest.fixture
def mock_zipfile(monkeypatch):
    mock_obj = mock.MagicMock(name='ZipFile')
    filenames = ('dir1/', 'dir1/filename1', 'dir1/filename2')
    mock_obj.return_value.__enter__.return_value.namelist.return_value = filenames
    monkeypatch.setattr('oilele.oilala.ZipFile', mock_obj)
    yield mock_obj
    print(f'{mock_obj} calls: {mock_obj.mock_calls}')


@pytest.mark.parametrize('pygame_version', (1, 2))
def test_main(mock_pil_image, mock_pdf2image, mock_pygame, pygame_version):
    mock_pygame[0].vernum.major = pygame_version
    mock_pdf2image.pdfinfo_from_path.return_value = {'Page rot': '3'}
    images = [
        mock.Mock(name='pdf_image1'),
        mock.Mock(name='pdf_image2'),
        mock.Mock(name='pdf_image3'),
    ]
    mock_pdf2image.convert_from_path.return_value = images

    main(['test'])

    for m in mock_pdf2image.convert_from_path.return_value:
        print(f'{m} calls: {m.mock_calls}')

    mock_pdf2image.pdfinfo_from_path.assert_called_once_with('test')
    mock_pdf2image.convert_from_path.assert_called_once_with('test')
    mock_pygame[0].display.set_caption.assert_called_with('1/3 - test')
    image = images[0].rotate.return_value.convert.return_value
    mock_pygame[0].image.fromstring.assert_called_with(image.tobytes.return_value, image.size, image.mode)


def test_main_cbz(mock_pil_image, mock_pdf2image, mock_pygame, mock_zipfile):
    mock_pdf2image.exceptions.PDFPageCountError = Exception
    mock_pdf2image.pdfinfo_from_path.side_effect = mock_pdf2image.exceptions.PDFPageCountError
    main(['test'])
    mock_pygame[0].display.set_caption.assert_called_with('1/2 - test')



import os
from abc import ABC, abstractmethod

import attr


@attr.s
class ComicScreen(ABC):
    images_count: int = attr.ib()
    file_name: str = attr.ib(converter=os.path.basename)
    _log = attr.ib()

    @abstractmethod
    def show(self, image, image_index: int):
        ...



try:
    from configargparse import ArgumentParser, ArgumentDefaultsHelpFormatter, Namespace
except ModuleNotFoundError:
    from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter, Namespace
import sys

from . import logging_utils


class LoggingArgumentParser(ArgumentParser):
    def __init__(self, *args, app_name: str = None, **kwargs):
        super(LoggingArgumentParser, self).__init__(*args, **kwargs)
        try:
            self.add_argument('--config', '-c', is_config_file=True, help='{} config file'.format(app_name))
        except TypeError:
            pass
        g = self.add_mutually_exclusive_group()
        g.add_argument('-q', '--quiet', action='store_true')
        g.add_argument('-v', '--verbose', action='store_true')
        if app_name is not None:
            self.app_name = app_name
        else:
            fr = next(sys._current_frames().values().__iter__()).f_back
            self.app_name = fr.f_globals['__name__'] if fr else None

    def parse_args(self, *args, **kwargs):
        cfg = super(LoggingArgumentParser, self).parse_args(*args, **kwargs)
        log_file = f'{self.app_name}.log' if self.app_name else None
        cfg.log = logging_utils.get_logger(self.app_name, verbose=cfg.verbose, quiet=cfg.quiet, with_file=log_file)
        return cfg


def arg_parser(description: str) -> ArgumentParser:
    parser = ArgumentParser(description=description, formatter_class=ArgumentDefaultsHelpFormatter)
    return parser


def with_quiet_verbose(
    app_name: str, parser: ArgumentParser = None, argv: list = None, logfile: str = None
) -> Namespace:
    """
    Optionally create a parser, add --quiet/--verbose and return parsed args with `.log`
    """
    if not parser:
        parser = arg_parser(description='{} arguments'.format(app_name))
    parser.add_argument('--config', '-c', is_config_file=True, help='{} config file'.format(app_name))
    g = parser.add_mutually_exclusive_group()
    g.add_argument('-q', '--quiet', action='store_true')
    g.add_argument('-v', '--verbose', action='store_true')
    if argv is None:
        argv = sys.argv[1:]
    cfg = parser.parse_args(argv)
    if logfile:
        logfile = logfile.format(**cfg.__dict__)
    cfg.log = logging_utils.get_logger(app_name, verbose=cfg.verbose, quiet=cfg.quiet, with_file=logfile)
    return cfg



import io
import logging
import sys

from kivy import Config
Config.set('graphics', 'multisamples', '0')
import os
# os.environ['KIVY_GL_BACKEND'] = 'angle_sdl2'
# os.environ['KIVY_GL_BACKEND'] = 'gl'
import kivy.app
import kivy.uix.button
import kivy.uix.image
import kivy.uix.scatter
import PIL


class KivyApp(kivy.app.App):
    def __init__(self, title: str, filename: str, *args, **kwargs):
        super(KivyApp, self).__init__(*args, **kwargs)
        self.title = title
        self.filename = filename
        self._log = logging.getLogger(__name__)
        self.nick_canvas = None

    def set_pil_image(self, image: PIL.Image.Image):
        data = io.BytesIO()
        image.save(data, format='png')
        im = kivy.core.image.Image(data, ext="png")
        self.set_image(im)

    def set_image(self, image):
        self.nick_canvas.add_widget(kivy.uix.image(texture=image.texture))

    def build(self):
        print('build')
        try:
            self.nick_canvas = kivy.uix.scatter.Scatter()
        except BaseException as e:
            self._log.exception(e)
        print('scatter')
        return self.nick_canvas

    def on_touch_down(self, touch):
        self._log.debug(f'Touch down: {touch}')
        return False

    def on_touch_up(self, touch):
        self._log.debug(f'Touch up: {touch}')
        return False


class MyApp(kivy.app.App):
    def build(self):
        return kivy.uix.button.Button(label='Nick')


if __name__ == '__main__':
    MyApp().run()
    app = KivyApp('Loading...', sys.argv[1])
    app.run()
    app.set_pil_image(PIL.Image.open(sys.argv[1]))



import os
import shutil
import sys
import typing
from oilele.lib.parse_args import LoggingArgumentParser as ArgumentParser

try:
    from unrar.rarfile import RarFile

    UNRAR_ENABLED = True
except (ImportError, LookupError) as e:
    UNRAR_ENABLED = False
    if '-v' in sys.argv or '--verbose' in sys.argv:
        print(e)
from zipfile import ZipFile

import attr
import pdf2image
from PIL import Image

from .screen.comic_screen import ComicScreen

SCREENS: typing.Dict[str, ComicScreen] = {}
try:
    from .screen.comic_screen_inky import ComicScreenInky

    INKY_ENABLED = True
    SCREENS['inky'] = ComicScreenInky  # type:ignore
except ImportError as e:
    INKY_ENABLED = False
    if '-v' in sys.argv or '--verbose' in sys.argv:
        print(e)

try:
    from .screen.comic_screen_kivy import ComicScreenKivy

    KIVY_ENABLED = True
    SCREENS['kivy'] = ComicScreenKivy  # type:ignore
except ImportError as e:
    KIVY_ENABLED = False
    if '-v' in sys.argv or '--verbose' in sys.argv:
        print(e)

if shutil.which('chafa'):
    from .screen.comic_screen_chafa import ComicScreenChafa

    CHAFA_ENABLED = True
    SCREENS['ascii'] = ComicScreenChafa  # type:ignore
else:
    CHAFA_ENABLED = False

os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
from .screen.comic_screen_pygame import ComicScreenPygame  # noqa: E402


def parse_args(argv: list):
    parser = ArgumentParser()
    parser.add_argument('filein')
    if SCREENS:
        g = parser.add_mutually_exclusive_group()
    for k in SCREENS:
        g.add_argument(f'--{k}', f'-{k.replace("-", "")[0].upper()}', action='store_true')
    parser.add_argument('--page', '-p', default=1, type=int, help='Initial page')
    return parser.parse_args(argv)


@attr.s
class OilalaImages(object):
    # this will contain either PIL or pygame image objects, based on the input
    images: list = attr.ib()
    _log = attr.ib()
    file_name: str = attr.ib(default='', converter=os.path.basename)
    curr_index: int = attr.ib(default=0)
    rotate: int = attr.ib(converter=int, default=0)

    @property
    def curr_image(self):
        image = self.images[self.curr_index]
        if self.rotate:
            image = image.rotate(self.rotate, expand=True)
        return image

    def next(self):
        self.curr_index = (self.curr_index + 1) % len(self.images)
        return self.curr_image

    def prev(self):
        self.curr_index = (self.curr_index - 1) % len(self.images)
        return self.curr_image


@attr.s
class ComicManager(object):
    screen: ComicScreen = attr.ib()
    images: OilalaImages = attr.ib()
    log = attr.ib()
    start_page: int = attr.ib(default=1)
    visible: bool = attr.ib(default=False)

    def __attrs_post_init__(self):
        self.images.curr_index = self.start_page - 1

    @property
    def curr_image(self):
        return self.images.curr_image

    def next(self):
        self.images.next()
        if self.visible:
            self.show()

    def prev(self):
        self.images.prev()
        if self.visible:
            self.show()

    def show(self, image_changed=True):
        self.visible = True
        return self.screen.show(self.curr_image, self.images.curr_index)


def images_from_pdf(file_name: str, log) -> OilalaImages:
    pdf_info = pdf2image.pdfinfo_from_path(file_name)
    log.debug(f'pdf_info: {pdf_info}')
    rotate = pdf_info.get('Page rot')
    pdf_images = pdf2image.convert_from_path(file_name)
    # see https://stackoverflow.com/questions/67103934 for the mypy issue
    return OilalaImages(pdf_images, log=log, file_name=file_name, rotate=rotate)  # type: ignore


def images_from_rar_archive(file_name: str, log) -> OilalaImages:
    images_list = list()
    with RarFile(file_name, 'r') as archive_file:
        for image_name in sorted(n for n in archive_file.namelist() if not n.endswith('/')):
            try:
                log.debug(image_name)
                images_list.append(Image.open(archive_file.open(image_name, 'r')))
            except Exception as e:
                log.exception(e)
                log.error(f'Error while adding {image_name} as an image from {file_name}: {e}')
    # see https://stackoverflow.com/questions/67103934 for the mypy issue
    return OilalaImages(images_list, log=log, file_name=file_name)  # type: ignore


def images_from_zip_archive(file_name: str, log) -> OilalaImages:
    images_list = list()
    with ZipFile(file_name, 'r') as archive_file:
        for image_name in sorted(n for n in archive_file.namelist() if not n.endswith('/')):
            try:
                log.debug(image_name)
                images_list.append(Image.open(archive_file.open(image_name, 'r')))
            except Exception as e:
                log.exception(e)
                log.error(f'Error while adding {image_name} as an image from {file_name}: {e}')
    # see https://stackoverflow.com/questions/67103934 for the mypy issue
    return OilalaImages(images_list, log=log, file_name=file_name)  # type: ignore


def images_from_archive(file_name: str, log) -> OilalaImages:
    extractor_funcs = [images_from_pdf, images_from_zip_archive]
    if UNRAR_ENABLED:
        extractor_funcs.append(images_from_rar_archive)
    for extractor in extractor_funcs:
        try:
            images_list = extractor(file_name, log)
            return images_list
        except Exception as e:
            log.debug(f'Error while opening {file_name} via {extractor}: {e}')
    # see https://stackoverflow.com/questions/67103934 for the mypy issue
    return OilalaImages(list(), log, file_name=file_name)  # type: ignore


def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]
    cfg = parse_args(argv)

    try:
        pdf_info = pdf2image.pdfinfo_from_path(cfg.filein)
        cfg.log.debug(f'pdf_info: {pdf_info}')
        rotate = pdf_info.get('Page rot')
        pdf_images = pdf2image.convert_from_path(cfg.filein)
        images = OilalaImages(pdf_images, log=cfg.log, file_name=cfg.filein, rotate=rotate)
    except pdf2image.exceptions.PDFPageCountError as e:
        cfg.log.debug(e)
        images = images_from_archive(cfg.filein, cfg.log)
        # images = OilalaImages(pyg_images, cfg.log, file_name=cfg.filein)
    screen = None
    for k, m in SCREENS.items():
        if getattr(cfg, k, False):
            screen = m(images_count=len(images.images), file_name=cfg.filein, log=cfg.log)
    if screen is None:
        screen = ComicScreenPygame(images_count=len(images.images), file_name=cfg.filein, log=cfg.log)

    mgr = ComicManager(screen, images, cfg.log, start_page=cfg.page)
    screen.main_loop(mgr)


if __name__ == '__main__':
    main()



import signal

import attr
import inky

try:
    import RPi.GPIO as GPIO
# GPIO reports a RuntimeError if imported on a non raspberry PI host
except RuntimeError as e:
    raise ImportError(f'Unable to import GPIO: {e}')
from PIL import Image

from .comic_screen import ComicScreen


@attr.s
class ComicScreenInky(ComicScreen):
    force_rotation: int = attr.ib(default=None)
    BUTTONS = [5, 6, 16, 24]  # Gpio pins for each button (from top to bottom)
    LABELS = ['A', 'B', 'C', 'D']  # These correspond to buttons A, B, C and D respectively

    def __attrs_post_init__(self):
        self._curr_image = None

        try:
            self.inky = inky.auto(verbose=True)
        except Exception as e:
            self._log.debug(f'Exception detecting Inky device: {e}. Using Inky7Colour')
            self.inky = inky.Inky7Colour()

        self.inky_ratio = self._ratio(self.inky.resolution)

    # "handle_button" will be called every time a button is pressed
    # It receives one argument: the associated input pin.
    def handle_button(self, pin: int):
        label = self.LABELS[self.BUTTONS.index(pin)]
        if label == 'A':
            self.mgr.next()
        elif label == 'B':
            self.mgr.prev()
        elif label == 'C':
            rotation = 0
            if self.force_rotation is not None:
                rotation = self.force_rotation
            self.force_rotation = (rotation + 90) % 360
            self.mgr.show()
        elif label == 'D':
            self._log.info(f'{label} ({pin}) pressed - stopping')
            self.looping = False
        else:
            self._log.info(f'{label} ({pin}) pressed')
        signal.raise_signal(signal.SIGUSR1)

    def _ratio(self, size: tuple) -> float:
        """This is to ensure we use the same ratio during calculations"""
        return size[0] / size[1]

    def _required_rotation(self, image):
        if self.force_rotation is not None:
            return self.force_rotation
        image_ratio = self._ratio(image.size)
        if (self.inky_ratio > 1 and image_ratio < 1) or (self.inky_ratio < 1 and image_ratio > 1):
            # by default, rotate 90 degrees counter-clockwise
            return 270
        return 0

    def show(self, image, image_index: int):
        title = f'{image_index + 1}/{self.images_count} - {self.file_name}'
        self._log.info(title)

        inky_image = Image.new('RGBA', self.inky.resolution, (0, 0, 0, 0))
        rotation = self._required_rotation(image)
        if rotation:
            image = image.rotate(rotation, expand=True)
        image.thumbnail(self.inky.resolution)
        inky_image.paste(
            image, box=[round(i / 2) for i in (inky_image.size[0] - image.size[0], inky_image.size[1] - image.size[1])]
        )
        self._log.debug(f'Resized image: {image.size} -> {inky_image.size}')
        self.inky.set_image(inky_image, saturation=0.5)
        self.inky.show()

    def main_loop_base(self):
        self.mgr.show()
        self.looping = True
        while self.looping:
            received_signal = signal.sigwait((signal.SIGUSR1,))
            self.log._debug(f'{received_signal=}')

    def main_loop(self, mgr):
        self.mgr = mgr
        GPIO.setmode(GPIO.BCM)  # Set up RPi.GPIO with the "BCM" numbering scheme

        # Buttons connect to ground when pressed, so we should set them up
        # with a "PULL UP", which weakly pulls the input signal to 3.3V.
        GPIO.setup(self.BUTTONS, GPIO.IN, pull_up_down=GPIO.PUD_UP)

        # Loop through out buttons and attach the "handle_button" function to each
        # We're watching the "FALLING" edge (transition from 3.3V to Ground) and
        # picking a generous bouncetime of 250ms to smooth out button presses.
        for pin in self.BUTTONS:
            GPIO.add_event_detect(pin, GPIO.FALLING, self.handle_button, bouncetime=250)

        self.main_loop_base()



import attr
import pygame
import PIL

from .comic_screen import ComicScreen


def is_mouse_or_key(pyg_event, mouse_button, key) -> bool:
    return (pyg_event.type == pygame.MOUSEBUTTONDOWN and pyg_event.button == mouse_button) or (
        pyg_event.type == pygame.KEYDOWN and pyg_event.key == key
    )


def is_next_event(pyg_event) -> bool:
    return is_mouse_or_key(pyg_event, 1, pygame.K_RIGHT)


def is_prev_event(pyg_event) -> bool:
    return is_mouse_or_key(pyg_event, 3, pygame.K_LEFT)


def is_quit_event(pyg_event) -> bool:
    return pyg_event.type == pygame.QUIT or getattr(pyg_event, 'key', None) == pygame.K_q


@attr.s
class ComicScreenPygame(ComicScreen):
    def __attrs_post_init__(self):
        self._curr_image = None
        self._curr_pyg_image = None
        pygame.display.init()
        self.screen = pygame.display.set_mode((800, 600), pygame.RESIZABLE)  # | pygame.HWSURFACE | pygame.DOUBLEBUF)
        pygame.display.set_caption(f'Loading {self.file_name}...')

    def show(self, image: PIL.Image.Image, image_index: int):
        if image != self._curr_image:
            self._curr_image = image
            pygame.display.set_caption(f'{image_index + 1}/{self.images_count} - {self.file_name}')
            image = image.convert('RGBA')
            self._curr_scr_image = image
        else:
            image = self._curr_scr_image
        self._log.debug(f'Thumbnail for: {image}')
        image.thumbnail(self.screen.get_size())
        self._log.debug(f'New size: {image.size} (screen: {self.screen.get_size()})')
        surf = pygame.image.fromstring(image.tobytes(), image.size, image.mode).convert()
        self._log.debug(f'Surface: {surf}')
        self.screen.blit(surf, surf.get_rect())
        pygame.display.flip()

    def main_loop(self, mgr):
        mgr.show()
        looping = True
        while looping:
            for pyg_event in pygame.event.get():
                if is_quit_event(pyg_event):
                    self._log.debug(pyg_event)
                    looping = False
                elif is_next_event(pyg_event):
                    mgr.next()
                elif is_prev_event(pyg_event):
                    mgr.prev()
                elif pygame.vernum.major == 1 and pyg_event.type == pygame.VIDEORESIZE:
                    self._log.debug('VIDEORESIZE')
                    self._log.debug(pyg_event)
                    self.screen = pygame.display.set_mode(pyg_event.dict['size'], pygame.RESIZABLE)
                    mgr.show(image_changed=True)
                elif pygame.vernum.major > 1 and pyg_event.type == pygame.WINDOWSIZECHANGED:
                    self._log.debug('WINDOWSIZECHANGED')
                    mgr.show(image_changed=False)
                elif pyg_event.type != pygame.MOUSEMOTION:
                    self._log.debug(pyg_event)
        pygame.quit()
